pub(crate) fn parse_month_numerical(
input: &[u8],
modifiers: MonthNumerical,
) -> Option<ParsedItem<'_, Month>>Expand description
Parse the “month” component of a Date in the numerical format (e.g. “1” for January).
pub(crate) fn parse_month_numerical(
input: &[u8],
modifiers: MonthNumerical,
) -> Option<ParsedItem<'_, Month>>Parse the “month” component of a Date in the numerical format (e.g. “1” for January).