pub(crate) fn parse_month_short(
input: &[u8],
modifiers: MonthShort,
) -> Option<ParsedItem<'_, Month>>Expand description
Parse the “month” component of a Date in the abbreviated form (e.g. “Jan”).
pub(crate) fn parse_month_short(
input: &[u8],
modifiers: MonthShort,
) -> Option<ParsedItem<'_, Month>>Parse the “month” component of a Date in the abbreviated form (e.g. “Jan”).