pub(crate) fn parse_unix_timestamp_second(
input: &[u8],
modifiers: UnixTimestampSecond,
) -> Option<ParsedItem<'_, i128>>Expand description
Parse the Unix timestamp component with second precision, returning the value in nanoseconds.
pub(crate) fn parse_unix_timestamp_second(
input: &[u8],
modifiers: UnixTimestampSecond,
) -> Option<ParsedItem<'_, i128>>Parse the Unix timestamp component with second precision, returning the value in nanoseconds.